function BranchData() {
    this.position = -1;
    this.nodeLength = -1;
    this.src = null;
    this.evalFalse = 0;
    this.evalTrue = 0;

    this.init = function(position, nodeLength, src) {
        this.position = position;
        this.nodeLength = nodeLength;
        this.src = src;
        return this;
    }

    this.ranCondition = function(result) {
        if (result)
            this.evalTrue++;
        else
            this.evalFalse++;
    };

    this.pathsCovered = function() {
        var paths = 0;
        if (this.evalTrue > 0)
          paths++;
        if (this.evalFalse > 0)
          paths++;
        return paths;
    };

    this.covered = function() {
        return this.evalTrue > 0 && this.evalFalse > 0;
    };

    this.toJSON = function() {
        return '{"position":' + this.position
            + ',"nodeLength":' + this.nodeLength
            + ',"src":' + jscoverage_quote(this.src)
            + ',"evalFalse":' + this.evalFalse
            + ',"evalTrue":' + this.evalTrue + '}';
    };

    this.message = function() {
        if (this.evalTrue === 0 && this.evalFalse === 0)
            return 'Condition never evaluated         :\t' + this.src;
        else if (this.evalTrue === 0)
            return 'Condition never evaluated to true :\t' + this.src;
        else if (this.evalFalse === 0)
            return 'Condition never evaluated to false:\t' + this.src;
        else
            return 'Condition covered';
    };
}

BranchData.fromJson = function(jsonString) {
    var json = eval('(' + jsonString + ')');
    var branchData = new BranchData();
    branchData.init(json.position, json.nodeLength, json.src);
    branchData.evalFalse = json.evalFalse;
    branchData.evalTrue = json.evalTrue;
    return branchData;
};

BranchData.fromJsonObject = function(json) {
    var branchData = new BranchData();
    branchData.init(json.position, json.nodeLength, json.src);
    branchData.evalFalse = json.evalFalse;
    branchData.evalTrue = json.evalTrue;
    return branchData;
};

function buildBranchMessage(conditions) {
    var message = 'The following was not covered:';
    for (var i = 0; i < conditions.length; i++) {
        if (conditions[i] !== undefined && conditions[i] !== null && !conditions[i].covered())
          message += '\n- '+ conditions[i].message();
    }
    return message;
};

function convertBranchDataConditionArrayToJSON(branchDataConditionArray) {
    var array = [];
    var length = branchDataConditionArray.length;
    for (var condition = 0; condition < length; condition++) {
        var branchDataObject = branchDataConditionArray[condition];
        if (branchDataObject === undefined || branchDataObject === null) {
            value = 'null';
        } else {
            value = branchDataObject.toJSON();
        }
        array.push(value);
    }
    return '[' + array.join(',') + ']';
}

function convertBranchDataLinesToJSON(branchData) {
    if (branchData === undefined) {
        return '{}'
    }
    var json = '';
    for (var line in branchData) {
        if (json !== '')
            json += ','
        json += '"' + line + '":' + convertBranchDataConditionArrayToJSON(branchData[line]);
    }
    return '{' + json + '}';
}

function convertBranchDataLinesFromJSON(jsonObject) {
    if (jsonObject === undefined) {
        return {};
    }
    for (var line in jsonObject) {
        var branchDataJSON = jsonObject[line];
        if (branchDataJSON !== null) {
            for (var conditionIndex = 0; conditionIndex < branchDataJSON.length; conditionIndex ++) {
                var condition = branchDataJSON[conditionIndex];
                if (condition !== null) {
                    branchDataJSON[conditionIndex] = BranchData.fromJsonObject(condition);
                }
            }
        }
    }
    return jsonObject;
}
function jscoverage_quote(s) {
    return '"' + s.replace(/[\u0000-\u001f"\\\u007f-\uffff]/g, function (c) {
        switch (c) {
            case '\b':
                return '\\b';
            case '\f':
                return '\\f';
            case '\n':
                return '\\n';
            case '\r':
                return '\\r';
            case '\t':
                return '\\t';
            // IE doesn't support this
            /*
             case '\v':
             return '\\v';
             */
            case '"':
                return '\\"';
            case '\\':
                return '\\\\';
            default:
                return '\\u' + jscoverage_pad(c.charCodeAt(0).toString(16));
        }
    }) + '"';
}

function getArrayJSON(coverage) {
    var array = [];
    if (coverage === undefined)
        return array;

    var length = coverage.length;
    for (var line = 0; line < length; line++) {
        var value = coverage[line];
        if (value === undefined || value === null) {
            value = 'null';
        }
        array.push(value);
    }
    return array;
}

function jscoverage_serializeCoverageToJSON() {
    var json = [];
    for (var file in _$jscoverage) {
        var lineArray = getArrayJSON(_$jscoverage[file].lineData);
        var fnArray = getArrayJSON(_$jscoverage[file].functionData);

        json.push(jscoverage_quote(file) + ':{"lineData":[' + lineArray.join(',') + '],"functionData":[' + fnArray.join(',') + '],"branchData":' + convertBranchDataLinesToJSON(_$jscoverage[file].branchData) + '}');
    }
    return '{' + json.join(',') + '}';
}


function jscoverage_pad(s) {
    return '0000'.substr(s.length) + s;
}

function jscoverage_html_escape(s) {
    return s.replace(/[<>\&\"\']/g, function (c) {
        return '&#' + c.charCodeAt(0) + ';';
    });
}
try {
  if (typeof top === 'object' && top !== null && typeof top.opener === 'object' && top.opener !== null) {
    // this is a browser window that was opened from another window

    if (! top.opener._$jscoverage) {
      top.opener._$jscoverage = {};
    }
  }
}
catch (e) {}

try {
  if (typeof top === 'object' && top !== null) {
    // this is a browser window

    try {
      if (typeof top.opener === 'object' && top.opener !== null && top.opener._$jscoverage) {
        top._$jscoverage = top.opener._$jscoverage;
      }
    }
    catch (e) {}

    if (! top._$jscoverage) {
      top._$jscoverage = {};
    }
  }
}
catch (e) {}

try {
  if (typeof top === 'object' && top !== null && top._$jscoverage) {
    this._$jscoverage = top._$jscoverage;
  }
}
catch (e) {}
if (! this._$jscoverage) {
  this._$jscoverage = {};
}
if (! _$jscoverage['/combobox/local-data-source.js']) {
  _$jscoverage['/combobox/local-data-source.js'] = {};
  _$jscoverage['/combobox/local-data-source.js'].lineData = [];
  _$jscoverage['/combobox/local-data-source.js'].lineData[6] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[7] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[8] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[16] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[24] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[26] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[27] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[52] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[53] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[55] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[56] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[58] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[59] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[60] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[62] = 0;
  _$jscoverage['/combobox/local-data-source.js'].lineData[65] = 0;
}
if (! _$jscoverage['/combobox/local-data-source.js'].functionData) {
  _$jscoverage['/combobox/local-data-source.js'].functionData = [];
  _$jscoverage['/combobox/local-data-source.js'].functionData[0] = 0;
  _$jscoverage['/combobox/local-data-source.js'].functionData[1] = 0;
  _$jscoverage['/combobox/local-data-source.js'].functionData[2] = 0;
  _$jscoverage['/combobox/local-data-source.js'].functionData[3] = 0;
}
if (! _$jscoverage['/combobox/local-data-source.js'].branchData) {
  _$jscoverage['/combobox/local-data-source.js'].branchData = {};
  _$jscoverage['/combobox/local-data-source.js'].branchData['55'] = [];
  _$jscoverage['/combobox/local-data-source.js'].branchData['55'][1] = new BranchData();
  _$jscoverage['/combobox/local-data-source.js'].branchData['59'] = [];
  _$jscoverage['/combobox/local-data-source.js'].branchData['59'][1] = new BranchData();
}
_$jscoverage['/combobox/local-data-source.js'].branchData['59'][1].init(18, 26, 'd.indexOf(inputVal) !== -1');
function visit82_59_1(result) {
  _$jscoverage['/combobox/local-data-source.js'].branchData['59'][1].ranCondition(result);
  return result;
}_$jscoverage['/combobox/local-data-source.js'].branchData['55'][1].init(61, 9, '!inputVal');
function visit81_55_1(result) {
  _$jscoverage['/combobox/local-data-source.js'].branchData['55'][1].ranCondition(result);
  return result;
}_$jscoverage['/combobox/local-data-source.js'].lineData[6]++;
KISSY.add(function(S, require) {
  _$jscoverage['/combobox/local-data-source.js'].functionData[0]++;
  _$jscoverage['/combobox/local-data-source.js'].lineData[7]++;
  var Attribute = require('attribute');
  _$jscoverage['/combobox/local-data-source.js'].lineData[8]++;
  var util = require('util');
  _$jscoverage['/combobox/local-data-source.js'].lineData[16]++;
  return Attribute.extend({
  fetchData: function(inputVal, callback, context) {
  _$jscoverage['/combobox/local-data-source.js'].functionData[1]++;
  _$jscoverage['/combobox/local-data-source.js'].lineData[24]++;
  var parse = this.get('parse'), data = this.get('data');
  _$jscoverage['/combobox/local-data-source.js'].lineData[26]++;
  data = parse(inputVal, data);
  _$jscoverage['/combobox/local-data-source.js'].lineData[27]++;
  callback.call(context, data);
}}, {
  ATTRS: {
  data: {
  value: []}, 
  parse: {
  value: parser}}});
  _$jscoverage['/combobox/local-data-source.js'].lineData[52]++;
  function parser(inputVal, data) {
    _$jscoverage['/combobox/local-data-source.js'].functionData[2]++;
    _$jscoverage['/combobox/local-data-source.js'].lineData[53]++;
    var ret = [], count = 0;
    _$jscoverage['/combobox/local-data-source.js'].lineData[55]++;
    if (visit81_55_1(!inputVal)) {
      _$jscoverage['/combobox/local-data-source.js'].lineData[56]++;
      return data;
    }
    _$jscoverage['/combobox/local-data-source.js'].lineData[58]++;
    util.each(data, function(d) {
  _$jscoverage['/combobox/local-data-source.js'].functionData[3]++;
  _$jscoverage['/combobox/local-data-source.js'].lineData[59]++;
  if (visit82_59_1(d.indexOf(inputVal) !== -1)) {
    _$jscoverage['/combobox/local-data-source.js'].lineData[60]++;
    ret.push(d);
  }
  _$jscoverage['/combobox/local-data-source.js'].lineData[62]++;
  count++;
});
    _$jscoverage['/combobox/local-data-source.js'].lineData[65]++;
    return ret;
  }
});
