function BranchData() {
    this.position = -1;
    this.nodeLength = -1;
    this.src = null;
    this.evalFalse = 0;
    this.evalTrue = 0;

    this.init = function(position, nodeLength, src) {
        this.position = position;
        this.nodeLength = nodeLength;
        this.src = src;
        return this;
    }

    this.ranCondition = function(result) {
        if (result)
            this.evalTrue++;
        else
            this.evalFalse++;
    };

    this.pathsCovered = function() {
        var paths = 0;
        if (this.evalTrue > 0)
          paths++;
        if (this.evalFalse > 0)
          paths++;
        return paths;
    };

    this.covered = function() {
        return this.evalTrue > 0 && this.evalFalse > 0;
    };

    this.toJSON = function() {
        return '{"position":' + this.position
            + ',"nodeLength":' + this.nodeLength
            + ',"src":' + jscoverage_quote(this.src)
            + ',"evalFalse":' + this.evalFalse
            + ',"evalTrue":' + this.evalTrue + '}';
    };

    this.message = function() {
        if (this.evalTrue === 0 && this.evalFalse === 0)
            return 'Condition never evaluated         :\t' + this.src;
        else if (this.evalTrue === 0)
            return 'Condition never evaluated to true :\t' + this.src;
        else if (this.evalFalse === 0)
            return 'Condition never evaluated to false:\t' + this.src;
        else
            return 'Condition covered';
    };
}

BranchData.fromJson = function(jsonString) {
    var json = eval('(' + jsonString + ')');
    var branchData = new BranchData();
    branchData.init(json.position, json.nodeLength, json.src);
    branchData.evalFalse = json.evalFalse;
    branchData.evalTrue = json.evalTrue;
    return branchData;
};

BranchData.fromJsonObject = function(json) {
    var branchData = new BranchData();
    branchData.init(json.position, json.nodeLength, json.src);
    branchData.evalFalse = json.evalFalse;
    branchData.evalTrue = json.evalTrue;
    return branchData;
};

function buildBranchMessage(conditions) {
    var message = 'The following was not covered:';
    for (var i = 0; i < conditions.length; i++) {
        if (conditions[i] !== undefined && conditions[i] !== null && !conditions[i].covered())
          message += '\n- '+ conditions[i].message();
    }
    return message;
};

function convertBranchDataConditionArrayToJSON(branchDataConditionArray) {
    var array = [];
    var length = branchDataConditionArray.length;
    for (var condition = 0; condition < length; condition++) {
        var branchDataObject = branchDataConditionArray[condition];
        if (branchDataObject === undefined || branchDataObject === null) {
            value = 'null';
        } else {
            value = branchDataObject.toJSON();
        }
        array.push(value);
    }
    return '[' + array.join(',') + ']';
}

function convertBranchDataLinesToJSON(branchData) {
    if (branchData === undefined) {
        return '{}'
    }
    var json = '';
    for (var line in branchData) {
        if (json !== '')
            json += ','
        json += '"' + line + '":' + convertBranchDataConditionArrayToJSON(branchData[line]);
    }
    return '{' + json + '}';
}

function convertBranchDataLinesFromJSON(jsonObject) {
    if (jsonObject === undefined) {
        return {};
    }
    for (var line in jsonObject) {
        var branchDataJSON = jsonObject[line];
        if (branchDataJSON !== null) {
            for (var conditionIndex = 0; conditionIndex < branchDataJSON.length; conditionIndex ++) {
                var condition = branchDataJSON[conditionIndex];
                if (condition !== null) {
                    branchDataJSON[conditionIndex] = BranchData.fromJsonObject(condition);
                }
            }
        }
    }
    return jsonObject;
}
function jscoverage_quote(s) {
    return '"' + s.replace(/[\u0000-\u001f"\\\u007f-\uffff]/g, function (c) {
        switch (c) {
            case '\b':
                return '\\b';
            case '\f':
                return '\\f';
            case '\n':
                return '\\n';
            case '\r':
                return '\\r';
            case '\t':
                return '\\t';
            // IE doesn't support this
            /*
             case '\v':
             return '\\v';
             */
            case '"':
                return '\\"';
            case '\\':
                return '\\\\';
            default:
                return '\\u' + jscoverage_pad(c.charCodeAt(0).toString(16));
        }
    }) + '"';
}

function getArrayJSON(coverage) {
    var array = [];
    if (coverage === undefined)
        return array;

    var length = coverage.length;
    for (var line = 0; line < length; line++) {
        var value = coverage[line];
        if (value === undefined || value === null) {
            value = 'null';
        }
        array.push(value);
    }
    return array;
}

function jscoverage_serializeCoverageToJSON() {
    var json = [];
    for (var file in _$jscoverage) {
        var lineArray = getArrayJSON(_$jscoverage[file].lineData);
        var fnArray = getArrayJSON(_$jscoverage[file].functionData);

        json.push(jscoverage_quote(file) + ':{"lineData":[' + lineArray.join(',') + '],"functionData":[' + fnArray.join(',') + '],"branchData":' + convertBranchDataLinesToJSON(_$jscoverage[file].branchData) + '}');
    }
    return '{' + json.join(',') + '}';
}


function jscoverage_pad(s) {
    return '0000'.substr(s.length) + s;
}

function jscoverage_html_escape(s) {
    return s.replace(/[<>\&\"\']/g, function (c) {
        return '&#' + c.charCodeAt(0) + ';';
    });
}
try {
  if (typeof top === 'object' && top !== null && typeof top.opener === 'object' && top.opener !== null) {
    // this is a browser window that was opened from another window

    if (! top.opener._$jscoverage) {
      top.opener._$jscoverage = {};
    }
  }
}
catch (e) {}

try {
  if (typeof top === 'object' && top !== null) {
    // this is a browser window

    try {
      if (typeof top.opener === 'object' && top.opener !== null && top.opener._$jscoverage) {
        top._$jscoverage = top.opener._$jscoverage;
      }
    }
    catch (e) {}

    if (! top._$jscoverage) {
      top._$jscoverage = {};
    }
  }
}
catch (e) {}

try {
  if (typeof top === 'object' && top !== null && top._$jscoverage) {
    this._$jscoverage = top._$jscoverage;
  }
}
catch (e) {}
if (! this._$jscoverage) {
  this._$jscoverage = {};
}
if (! _$jscoverage['/menubutton.js']) {
  _$jscoverage['/menubutton.js'] = {};
  _$jscoverage['/menubutton.js'].lineData = [];
  _$jscoverage['/menubutton.js'].lineData[6] = 0;
  _$jscoverage['/menubutton.js'].lineData[7] = 0;
  _$jscoverage['/menubutton.js'].lineData[8] = 0;
  _$jscoverage['/menubutton.js'].lineData[9] = 0;
  _$jscoverage['/menubutton.js'].lineData[17] = 0;
  _$jscoverage['/menubutton.js'].lineData[18] = 0;
  _$jscoverage['/menubutton.js'].lineData[20] = 0;
  _$jscoverage['/menubutton.js'].lineData[22] = 0;
  _$jscoverage['/menubutton.js'].lineData[23] = 0;
  _$jscoverage['/menubutton.js'].lineData[24] = 0;
  _$jscoverage['/menubutton.js'].lineData[25] = 0;
  _$jscoverage['/menubutton.js'].lineData[27] = 0;
  _$jscoverage['/menubutton.js'].lineData[28] = 0;
  _$jscoverage['/menubutton.js'].lineData[32] = 0;
  _$jscoverage['/menubutton.js'].lineData[37] = 0;
  _$jscoverage['/menubutton.js'].lineData[38] = 0;
  _$jscoverage['/menubutton.js'].lineData[39] = 0;
  _$jscoverage['/menubutton.js'].lineData[41] = 0;
  _$jscoverage['/menubutton.js'].lineData[42] = 0;
  _$jscoverage['/menubutton.js'].lineData[45] = 0;
  _$jscoverage['/menubutton.js'].lineData[46] = 0;
  _$jscoverage['/menubutton.js'].lineData[50] = 0;
}
if (! _$jscoverage['/menubutton.js'].functionData) {
  _$jscoverage['/menubutton.js'].functionData = [];
  _$jscoverage['/menubutton.js'].functionData[0] = 0;
  _$jscoverage['/menubutton.js'].functionData[1] = 0;
  _$jscoverage['/menubutton.js'].functionData[2] = 0;
  _$jscoverage['/menubutton.js'].functionData[3] = 0;
}
if (! _$jscoverage['/menubutton.js'].branchData) {
  _$jscoverage['/menubutton.js'].branchData = {};
  _$jscoverage['/menubutton.js'].branchData['18'] = [];
  _$jscoverage['/menubutton.js'].branchData['18'][1] = new BranchData();
  _$jscoverage['/menubutton.js'].branchData['22'] = [];
  _$jscoverage['/menubutton.js'].branchData['22'][1] = new BranchData();
  _$jscoverage['/menubutton.js'].branchData['24'] = [];
  _$jscoverage['/menubutton.js'].branchData['24'][1] = new BranchData();
  _$jscoverage['/menubutton.js'].branchData['27'] = [];
  _$jscoverage['/menubutton.js'].branchData['27'][1] = new BranchData();
  _$jscoverage['/menubutton.js'].branchData['37'] = [];
  _$jscoverage['/menubutton.js'].branchData['37'][1] = new BranchData();
}
_$jscoverage['/menubutton.js'].branchData['37'][1].init(586, 37, 'cfg.mode === Editor.Mode.WYSIWYG_MODE');
function visit5_37_1(result) {
  _$jscoverage['/menubutton.js'].branchData['37'][1].ranCondition(result);
  return result;
}_$jscoverage['/menubutton.js'].branchData['27'][1].init(177, 9, 'cfg.elCls');
function visit4_27_1(result) {
  _$jscoverage['/menubutton.js'].branchData['27'][1].ranCondition(result);
  return result;
}_$jscoverage['/menubutton.js'].branchData['24'][1].init(50, 8, 'cfg.menu');
function visit3_24_1(result) {
  _$jscoverage['/menubutton.js'].branchData['24'][1].ranCondition(result);
  return result;
}_$jscoverage['/menubutton.js'].branchData['22'][1].init(146, 3, 'cfg');
function visit2_22_1(result) {
  _$jscoverage['/menubutton.js'].branchData['22'][1].ranCondition(result);
  return result;
}_$jscoverage['/menubutton.js'].branchData['18'][1].init(23, 31, 'SelectType || MenuButton.Select');
function visit1_18_1(result) {
  _$jscoverage['/menubutton.js'].branchData['18'][1].ranCondition(result);
  return result;
}_$jscoverage['/menubutton.js'].lineData[6]++;
KISSY.add(function(S, require) {
  _$jscoverage['/menubutton.js'].functionData[0]++;
  _$jscoverage['/menubutton.js'].lineData[7]++;
  var Editor = require('editor');
  _$jscoverage['/menubutton.js'].lineData[8]++;
  var util = require('util');
  _$jscoverage['/menubutton.js'].lineData[9]++;
  var MenuButton = require('menubutton');
  _$jscoverage['/menubutton.js'].lineData[17]++;
  Editor.prototype.addSelect = function(id, cfg, SelectType) {
  _$jscoverage['/menubutton.js'].functionData[1]++;
  _$jscoverage['/menubutton.js'].lineData[18]++;
  SelectType = visit1_18_1(SelectType || MenuButton.Select);
  _$jscoverage['/menubutton.js'].lineData[20]++;
  var self = this, prefixCls = self.get('prefixCls') + 'editor-';
  _$jscoverage['/menubutton.js'].lineData[22]++;
  if (visit2_22_1(cfg)) {
    _$jscoverage['/menubutton.js'].lineData[23]++;
    cfg.editor = self;
    _$jscoverage['/menubutton.js'].lineData[24]++;
    if (visit3_24_1(cfg.menu)) {
      _$jscoverage['/menubutton.js'].lineData[25]++;
      cfg.menu.zIndex = Editor.baseZIndex(Editor.ZIndexManager.SELECT);
    }
    _$jscoverage['/menubutton.js'].lineData[27]++;
    if (visit4_27_1(cfg.elCls)) {
      _$jscoverage['/menubutton.js'].lineData[28]++;
      cfg.elCls = prefixCls + cfg.elCls;
    }
  }
  _$jscoverage['/menubutton.js'].lineData[32]++;
  var s = new SelectType(util.mix({
  render: self.get('toolBarEl'), 
  prefixCls: prefixCls}, cfg)).render();
  _$jscoverage['/menubutton.js'].lineData[37]++;
  if (visit5_37_1(cfg.mode === Editor.Mode.WYSIWYG_MODE)) {
    _$jscoverage['/menubutton.js'].lineData[38]++;
    self.on('wysiwygMode', function() {
  _$jscoverage['/menubutton.js'].functionData[2]++;
  _$jscoverage['/menubutton.js'].lineData[39]++;
  s.set('disabled', false);
});
    _$jscoverage['/menubutton.js'].lineData[41]++;
    self.on('sourceMode', function() {
  _$jscoverage['/menubutton.js'].functionData[3]++;
  _$jscoverage['/menubutton.js'].lineData[42]++;
  s.set('disabled', true);
});
  }
  _$jscoverage['/menubutton.js'].lineData[45]++;
  self.addControl(id + '/select', s);
  _$jscoverage['/menubutton.js'].lineData[46]++;
  return s;
};
  _$jscoverage['/menubutton.js'].lineData[50]++;
  return MenuButton;
});
